@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12017 2020-03-26 05:57:40Z Lavender $
+# $Id: __init__.py 12048 2020-04-06 10:51:25Z Trista $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-03-26 14:57:40 +0900 (週四, 26 三月 2020) $
-# $Revision: 12017 $
+# $Author: Trista $ (last)
+# $Date: 2020-04-06 18:51:25 +0800 (週一, 06 四月 2020) $
+# $Revision: 12048 $
 
 import os
 import sys
@@ -496,55 +496,110 @@ def attachSettings(settingsDict, enablePaypal=False):
              break
 
     if not hasConfig:
-        if needShipping:
-            ADDING_OSCAR_ORDER_STATUS = {
-                'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'商品送貨中',
-                'OSCAR_ARRIVE_SEND_EMAIL_STATUS': u'商品已到貨',
-                'OSCAR_INITIAL_ORDER_STATUS': u'等待處理中',
-                'OSCAR_INITIAL_LINE_STATUS': '-',
-                'OSCAR_ORDER_RETURN_STATUS': u'商品退貨中',
-                'OSCAR_ORDER_PROCESSING_STATUS': u'商品送貨中',
-                'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
-                'OSCAR_ORDER_ARRIVE_STATUS': u'商品已到貨',
-                'OSCAR_ORDER_STATUS_PIPELINE': {
-                    u'等待處理中': \
-                        (u'商品送貨中', u'訂單取消', u'測試用訂單'),
-                    u'商品送貨中': \
-                        (u'完成訂單', u'商品已到貨', 
-                         u'訂單取消', u'測試用訂單'),
-                    u'商品已到貨': (u'完成訂單', u'訂單取消', u'測試用訂單',),
-                    u'訂單取消': (u'測試用訂單', ),
-                    u'完成訂單': (u'測試用訂單', ),
+        
+        language_code = settingsDict['LANGUAGE_CODE'] if 'LANGUAGE_CODE' in settingsDict else 'en'
+        if (language_code == 'zh-hant') or (language_code == 'zh') or (language_code == 'zh-hans'):
+            if needShipping:
+                ADDING_OSCAR_ORDER_STATUS = {
+                    'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'商品送貨中',
+                    'OSCAR_ARRIVE_SEND_EMAIL_STATUS': u'商品已到貨',
+                    'OSCAR_INITIAL_ORDER_STATUS': u'等待處理中',
+                    'OSCAR_INITIAL_LINE_STATUS': '-',
+                    'OSCAR_ORDER_RETURN_STATUS': u'商品退貨中',
+                    'OSCAR_ORDER_PROCESSING_STATUS': u'商品送貨中',
+                    'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
+                    'OSCAR_ORDER_ARRIVE_STATUS': u'商品已到貨',
+                    'OSCAR_ORDER_STATUS_PIPELINE': {
+                        u'等待處理中': \
+                            (u'商品送貨中', u'訂單取消', u'測試用訂單'),
+                        u'商品送貨中': \
+                            (u'完成訂單', u'商品已到貨', 
+                             u'訂單取消', u'測試用訂單'),
+                        u'商品已到貨': (u'完成訂單', u'訂單取消', u'測試用訂單',),
+                        u'訂單取消': (u'測試用訂單', ),
+                        u'完成訂單': (u'測試用訂單', ),
 
-                    u'商品退貨中': (u'完成退貨', u'測試用訂單'),
-                    u'完成退貨': (u'測試用訂單',),
-                    u'測試用訂單': (u'等待處理中',),
-                },
-                'OSCAR_ORDER_STATUS': [
-                    (u'等待處理中', u'等待處理中'),
-                    (u'商品送貨中', u'商品送貨中'),
-                    (u'商品已到貨', u'商品已到貨'),
-                    (u'訂單取消', u'訂單取消'),
-                    (u'完成訂單', u'完成訂單'),
-                    (u'商品退貨中', u'商品退貨中'),
-                    (u'完成退貨', u'完成退貨'),
-                    (u'測試用訂單', u'測試用訂單'),
-                ],
-            }
+                        u'商品退貨中': (u'完成退貨', u'測試用訂單'),
+                        u'完成退貨': (u'測試用訂單',),
+                        u'測試用訂單': (u'等待處理中',),
+                    },
+                    'OSCAR_ORDER_STATUS': [
+                        (u'等待處理中', u'等待處理中'),
+                        (u'商品送貨中', u'商品送貨中'),
+                        (u'商品已到貨', u'商品已到貨'),
+                        (u'訂單取消', u'訂單取消'),
+                        (u'完成訂單', u'完成訂單'),
+                        (u'商品退貨中', u'商品退貨中'),
+                        (u'完成退貨', u'完成退貨'),
+                        (u'測試用訂單', u'測試用訂單'),
+                    ],
+                }
+            else:
+                ADDING_OSCAR_ORDER_STATUS = {
+                    'OSCAR_INITIAL_ORDER_STATUS': u'完成訂單',
+                    'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
+                    'OSCAR_INITIAL_LINE_STATUS': '-',
+                    'OSCAR_ORDER_STATUS_PIPELINE': {
+                        u'完成訂單': (u'測試用訂單', ),
+                        u'測試用訂單': (u'完成訂單',),
+                    },
+                    'OSCAR_ORDER_STATUS': [
+                        (u'完成訂單', u'完成訂單'),
+                        (u'測試用訂單', u'測試用訂單'),
+                    ],
+                }
         else:
-            ADDING_OSCAR_ORDER_STATUS = {
-                'OSCAR_INITIAL_ORDER_STATUS': u'完成訂單',
-                'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
-                'OSCAR_INITIAL_LINE_STATUS': '-',
-                'OSCAR_ORDER_STATUS_PIPELINE': {
-                    u'完成訂單': (u'測試用訂單', ),
-                    u'測試用訂單': (u'完成訂單',),
-                },
-                'OSCAR_ORDER_STATUS': [
-                    (u'完成訂單', u'完成訂單'),
-                    (u'測試用訂單', u'測試用訂單'),
-                ],
-            }
+            if needShipping:
+                ADDING_OSCAR_ORDER_STATUS = {
+                    'OSCAR_PROCESSING_SEND_EMAIL_STATUS': u'Being processed',
+                    'OSCAR_ARRIVE_SEND_EMAIL_STATUS': u'Delivered',
+                    'OSCAR_INITIAL_ORDER_STATUS': u'Pending',
+                    'OSCAR_INITIAL_LINE_STATUS': '-',
+                    'OSCAR_ORDER_RETURN_STATUS': u'Being returned',
+                    'OSCAR_ORDER_PROCESSING_STATUS': u'Shipping',
+                    'OSCAR_ORDER_COMPLETE_STATUS': u'Order completed',
+                    'OSCAR_ORDER_ARRIVE_STATUS': u'Delivered',
+                    'OSCAR_ORDER_STATUS_PIPELINE': {
+                        u'Pending': \
+                            (u'Shipping', u'Cancelled', u'Testing order'),
+                        u'Shipping': \
+                            (u'Order completed', u'Delivered', 
+                             u'Cancelled', u'Testing order'),
+                        u'Delivered': (u'Order completed', u'Cancelled', u'Testing order',),
+                        u'Cancelled': (u'Testing order', ),
+                        u'Order completed': (u'Testing order', ),
+
+                        u'Being returned': (u'Returned', u'Testing order'),
+                        u'Returned': (u'Testing order',),
+                        u'Testing order': (u'Pending',),
+                    },
+                    'OSCAR_ORDER_STATUS': [
+                        (u'Pending', u'Pending'),
+                        (u'Shipping', u'Shipping'),
+                        (u'Delivered', u'Arrived'),
+                        (u'Cancelled', u'Cancelled'),
+                        (u'Order completed', u'Order completed'),
+                        (u'Being returned', u'Being returned'),
+                        (u'Returned', u'Returned'),
+                        (u'Testing order', u'Testing order'),
+                    ],
+                }
+            else:
+                ADDING_OSCAR_ORDER_STATUS = {
+                    'OSCAR_INITIAL_ORDER_STATUS': u'Order completed',
+                    'OSCAR_ORDER_COMPLETE_STATUS': u'Order completed',
+                    'OSCAR_INITIAL_LINE_STATUS': '-',
+                    'OSCAR_ORDER_STATUS_PIPELINE': {
+                        u'Order completed': (u'Testing order', ),
+                        u'Testing order': (u'Order completed',),
+                    },
+                    'OSCAR_ORDER_STATUS': [
+                        (u'Order completed', u'Order completed'),
+                        (u'Testing order', u'Testing order'),
+                    ],
+                }        
+                
+        
 
         update(settingsDict, ADDING_OSCAR_ORDER_STATUS)
     else:
